@@ -11,11 +11,11 @@ from typing import Awaitable, Callable, Optional
 from async_upnp_client.const import AddressTupleVXType, NotificationSubType, SsdpSource
 from async_upnp_client.ssdp import (
     SSDP_DISCOVER,
-    SsdpHeaders,
     SsdpProtocol,
     determine_source_target,
     get_ssdp_socket,
 )
+from async_upnp_client.utils import CaseInsensitiveDict
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,9 +25,9 @@ class SsdpAdvertisementListener:
 
     def __init__(
         self,
-        on_alive: Optional[Callable[[SsdpHeaders], Awaitable]] = None,
-        on_byebye: Optional[Callable[[SsdpHeaders], Awaitable]] = None,
-        on_update: Optional[Callable[[SsdpHeaders], Awaitable]] = None,
+        on_alive: Optional[Callable[[CaseInsensitiveDict], Awaitable]] = None,
+        on_byebye: Optional[Callable[[CaseInsensitiveDict], Awaitable]] = None,
+        on_update: Optional[Callable[[CaseInsensitiveDict], Awaitable]] = None,
         source: Optional[AddressTupleVXType] = None,
         target: Optional[AddressTupleVXType] = None,
         loop: Optional[AbstractEventLoop] = None,
@@ -41,7 +41,9 @@ class SsdpAdvertisementListener:
         self._loop: AbstractEventLoop = loop or asyncio.get_event_loop()
         self._transport: Optional[BaseTransport] = None
 
-    async def _async_on_data(self, request_line: str, headers: SsdpHeaders) -> None:
+    async def _async_on_data(
+        self, request_line: str, headers: CaseInsensitiveDict
+    ) -> None:
         """Handle data."""
         if headers.get("MAN") == SSDP_DISCOVER:
             # Ignore discover packets.
